// -*-Mode: C++;-*-
/**
 * This class is designed to create an dialog with variables
 * counts of text-input fields.
 *
 * @short Textinputdialog
 * @see QWidget
 * @see QDialog
 */
#ifndef CMultiTextInput_included
#define CMultiTextInput_included

#include <qstrlist.h>
#include <qlined.h>
#include <qpushbt.h>

#include "PatternPair.h"
#include "MultiTextInputData.h"

class CMultiTextInput : public CMultiTextInputData
{
    Q_OBJECT
public:
    CMultiTextInput(QWidget* parent = NULL,const char* name = NULL);
    virtual ~CMultiTextInput();
    void build_widgets(PatternList*which);
    PatternList*get_entries(bool emptys_too=FALSE);
private:
    QList<QWidget>*EditList;
private slots:
    void change_focus();

protected slots:
    void keyPressEvent(QKeyEvent*e);

};
#endif // CMultiTextInput_included
